SHA256
1
0
forked from pool/breeze-gtk

Sync with KDE:Frameworks5:LTS

OBS-URL: https://build.opensuse.org/package/show/KDE:Frameworks5/breeze-gtk?expand=0&rev=27
This commit is contained in:
Fabian Vogt 2016-09-23 18:20:20 +00:00 committed by Git OBS Bridge
parent e5ad1df950
commit 9691b1e658
3 changed files with 69 additions and 0 deletions

View File

@ -1,3 +1,11 @@
-------------------------------------------------------------------
Mon Sep 19 12:30:19 UTC 2016 - wbauer@tmo.at
- Re-add update_from_BreezeGTK.patch to fix the GTK theme settings on
upgrades from Leap 42.1, which shipped with BreezyGTK (boo#994832)
- build the proper theme for distributions which have gtk3 < 3.20
(13.2 and Leap 42.1)
-------------------------------------------------------------------
Thu Sep 15 15:53:55 UTC 2016 - fabian@ritter-vogt.de

View File

@ -25,6 +25,8 @@ License: LGPL-2.1
Group: System/GUI/KDE
Url: https://projects.kde.org/breeze-gtk
Source: http://download.kde.org/unstable/plasma/%{version}/%{name}-%{version}.tar.xz
# PATCH-FIX-OPENSUSE update_from_BreezeGTK.patch boo#994832 -- update user's config from the old BreezyGTK theme
Patch: update_from_BreezeGTK.patch
BuildRequires: cmake >= 2.8.12
BuildRequires: extra-cmake-modules
BuildRequires: fdupes
@ -68,10 +70,15 @@ A GTK+ theme created to match with the new Plasma 5 Breeze theme.
%prep
%setup -q
%patch -p1
chmod a-x COPYING* README.md
%build
%if 0%{?suse_version} > 1320 || (0%{?suse_version} == 1315 && 0%{?sle_version} > 120100)
%cmake_kf5 -- -DWITH_GTK3_VERSION=3.20
%else
%cmake_kf5
%endif
make %{?_smp_mflags}
%install

View File

@ -0,0 +1,54 @@
--- breeze-gtk-5.5.5.orig/kconf_update/main.cpp 2016-03-01 14:27:02.000000000 +0100
+++ breeze-gtk-5.5.5/kconf_update/main.cpp 2016-03-08 17:24:37.883095403 +0100
@@ -46,7 +46,7 @@ QString isGtkThemeInstalled(QString them
}
/*
* Check if gtk theme is already set to oxygen or Orion, if it is then we want to upgrade to the breeze theme
* gtkSettingsFile: filename to use
* settingsKey: ini group to read from
* returns: full path to settings file
@@ -67,9 +67,9 @@ bool isGtkThemeSetToOldTheme(QString gtk
if (!settingsKey.isNull()) {
gtkrcSettings.beginGroup(settingsKey);
}
- //if it is set to Oxygen or Orion then we want to upgrade it to Breeze
- if (gtkrcSettings.value("gtk-theme-name") == QLatin1String("oxygen-gtk") || gtkrcSettings.value("gtk-theme-name") == QLatin1String("Orion")) {
- qCDebug(GTKBREEZE) << "using oxygen or orion " << gtkrcSettings.value("gtk-theme-name");
+ //if it is set to Oxygen, BreezyGTK or Orion then we want to upgrade it to Breeze
+ if (gtkrcSettings.value("gtk-theme-name") == QLatin1String("oxygen-gtk") || gtkrcSettings.value("gtk-theme-name") == QLatin1String("BreezyGTK") || gtkrcSettings.value("gtk-theme-name") == QLatin1String("Orion")) {
+ qCDebug(GTKBREEZE) << "using oxygen, BreezyGTK or orion " << gtkrcSettings.value("gtk-theme-name");
return true;
} else {
return false;
@@ -98,11 +98,11 @@ int setGtk2()
bool needsUpdate = isGtkThemeSetToOldTheme(gtkrc2path, QString());
if (needsUpdate == false) {
- qCDebug(GTKBREEZE) << "gtkrc2 already exists and is not using oxygen or orion, quitting";
+ qCDebug(GTKBREEZE) << "gtkrc2 already exists and is not using oxygen, BreezyGTK or orion, quitting";
return 0;
}
- qCDebug(GTKBREEZE) << "no gtkrc2 file or oxygen/orion being used, setting to new theme";
+ qCDebug(GTKBREEZE) << "no gtkrc2 file or oxygen/BreezyGTK/orion being used, setting to new theme";
QFile gtkrc2writer(gtkrc2path);
bool opened = gtkrc2writer.open(QIODevice::WriteOnly | QIODevice::Text);
if (!opened) {
@@ -145,13 +145,13 @@ int setGtk3()
QString gtkrc3path = configPath + "/gtk-3.0/settings.ini";
bool needsUpdate = isGtkThemeSetToOldTheme(gtkrc3path, "Settings");
if ( !needsUpdate ) {
- qCDebug(GTKBREEZE) << "gtkrc3 already exists and is not using oxygen/orion, quitting";
+ qCDebug(GTKBREEZE) << "gtkrc3 already exists and is not using oxygen/BreezyGTK/orion, quitting";
return 0;
}
QDir dir = QFileInfo(gtkrc3path).dir();
dir.mkpath(dir.path());
- qCDebug(GTKBREEZE) << "no gtkrc3 file or oxygen/orion being used, setting to new theme";
+ qCDebug(GTKBREEZE) << "no gtkrc3 file or oxygen/BreezyGTK/orion being used, setting to new theme";
QFile gtkrc3writer(gtkrc3path);
bool opened = gtkrc3writer.open(QIODevice::WriteOnly | QIODevice::Text);
if (!opened) {
@@ -46,7 +46,7 @@ QString isGtkThemeInstalled(QString them
}
/*
- * Check if gtk theme is already set to oxygen or Orion, if it is then we want to upgrade to the breeze theme
+ * Check if gtk theme is already set to oxygen, BreezyGTK or Orion, if it is then we want to upgrade to the breeze theme
* gtkSettingsFile: filename to use
* settingsKey: ini group to read from